@@ -23,7 +23,9 @@ class HyperTag:
         self.root_dir = Path(self.db.get_hypertagfs_dir())
         os.makedirs(self.root_dir, exist_ok=True)
 
-    def search_image(self, *text_queries: str, top_k=10, path=False, score=False, _return=False):
+    def search_image(
+        self, *text_queries: str, cpu=None, top_k=10, path=0, score=0, verbose=0, _return=0
+    ):
         """ Execute a semantic search that returns best matching images """
         text_query = " ".join(text_queries)
         try:
@@ -36,7 +38,7 @@ class HyperTag:
         except ConnectionRefusedError:
             from .vectorizer import CLIPVectorizer
 
-            vectorizer = CLIPVectorizer()
+            vectorizer = CLIPVectorizer(cpu, verbose)
             results = vectorizer.search_image(text_query, path, top_k, score)
         if _return:
             return results
@@ -66,7 +68,7 @@ class HyperTag:
                 remote = False
 
         if not remote:
-            img_vectorizer = CLIPVectorizer()
+            img_vectorizer = CLIPVectorizer(verbose=1)
 
         for file_path in tqdm(compatible_files):
             if remote:
@@ -80,8 +82,7 @@ class HyperTag:
         if remote:
             rpc.root.update_image_index()
         else:
-            corpus_vectors, corpus_paths = img_vectorizer.get_image_corpus()
-            img_vectorizer.update_index(len(corpus_vectors))
+            img_vectorizer.update_index()
 
     def index_texts(self, rebuild=False, cache=False, cores: int = 0):
         """ Vectorize text files (needed for semantic search) """
@@ -131,7 +132,7 @@ class HyperTag:
         print("Starting inference...")
         # Compute embeddings
         if not remote:
-            vectorizer = TextVectorizer()
+            vectorizer = TextVectorizer(verbose=True)
         for file_path, sentences in tqdm(inference_tuples):
             if remote:
                 document_vector = json.loads(rpc.root.compute_text_embedding(json.dumps(sentences)))
@@ -155,8 +156,7 @@ class HyperTag:
         if remote:
             rpc.root.update_text_index()
         else:
-            corpus_vectors, corpus_paths = vectorizer.get_text_corpus()
-            vectorizer.update_index(len(corpus_vectors))
+            vectorizer.update_index()
 
     def search(self, *text_queries: str, path=False, top_k=10, score=False, _return=False):
         """ Execute a semantic search that returns best matching text documents """
@@ -279,10 +279,10 @@ class HyperTag:
             added_file_paths = visible_file_paths
         else:
             added_file_paths = self.add(*visible_file_paths)
-        import_path_dirs = set(str(import_path).split("/"))
+        import_path_dirs = set(str(Path(import_path).resolve()).split("/"))
         print("Adding tags...")
         for file_path in tqdm(added_file_paths):
-            self.auto_add_tags_from_path(file_path, import_path_dirs, verbose)
+            self.auto_add_tags_from_path(os.path.abspath(str(file_path)), import_path_dirs, verbose)
         self.db.conn.commit()
         self.mount(self.root_dir)
 
@@ -519,14 +519,14 @@ class HyperTag:
         self.mount(self.root_dir)
 
 
-def daemon():
+def daemon(cpu=None):
     """ Start daemon process """
     print("Starting up daemon...")
     from .daemon import start
     from multiprocessing import Process, set_start_method
 
     set_start_method("spawn")
-    p = Process(target=start)
+    p = Process(target=start, args=(cpu,))
     p.start()
     p.join()
 
